## Vectorization


This primitive is also used by [`Stacked.vmap`](scan.md#apply-blocks-in-parallel-with-vmap)
to apply an entire stack of blocks in parallel.

(This is a work in progress. Please contact dlwh for more information.)

::: haliax.vmap
